@@ -69,6 +69,8 @@
 #define COL_YEL  "\x1B[33m"
 #define COL_RESET "\033[0m"
 
+#define UNUSED(x) (void)(x)
+
 #define RET_IF_HSA_ERR(err) { \
   if ((err) != HSA_STATUS_SUCCESS) { \
     char err_val[12];                                                         \
@@ -192,6 +194,7 @@ static const uint32_t kValueFieldSize = 35;
 static const uint32_t kIndentSize = 2;
 
 static bool wsl_env = false;
+static bool dtif_env = false;
 
 enum rocmi_int_format {
   ROCMI_INT_FORMAT_DEC = 1,
@@ -238,6 +241,17 @@ static void DetectWSLEnvironment() {
   }
 }
 
+static void DetectDTIFEnvironment() {
+  char *var = getenv("HSA_ENABLE_DTIF");
+  if (var == NULL)
+    return;
+
+  if (0 == strncmp(var, "1", 1)) {
+    printf("HSA-DTIF environment detected.\n");
+    dtif_env = true;
+  }
+}
+
 static void printLabelInt(char const *l, int d, uint32_t indent_lvl = 0) {
   std::string ind(kIndentSize * indent_lvl, ' ');
 
@@ -265,6 +279,7 @@ static void printLabel(char const *l, bool newline = false,
   }
 }
 static void printValueStr(char const *s, bool newline = true) {
+  UNUSED(newline);
   printf("%-*s\n", kValueFieldSize, s);
 }
 
@@ -667,10 +682,10 @@ static void DisplayAgentInfo(agent_info_t *agent_i) {
   }
 
   printLabelStr("Chip ID:", int_to_string(agent_i->chip_id), 1);
-  if (!wsl_env)
+  if (!(wsl_env || dtif_env))
     printLabelStr("ASIC Revision:", int_to_string(agent_i->asic_revision), 1);
   printLabelStr("Cacheline Size:", int_to_string(agent_i->cacheline_size), 1);
-  if (!wsl_env || HSA_DEVICE_TYPE_GPU == agent_i->device_type)
+  if (!(wsl_env || dtif_env) || HSA_DEVICE_TYPE_GPU == agent_i->device_type)
     printLabelInt("Max Clock Freq. (MHz):", agent_i->max_clock_freq, 1);
   printLabelInt("BDFID:", agent_i->bdf_id, 1);
   printLabelInt("Internal Node ID:", agent_i->internal_node_id, 1);
@@ -678,7 +693,7 @@ static void DisplayAgentInfo(agent_info_t *agent_i) {
   printLabelInt("SIMDs per CU:", agent_i->simds_per_cu, 1);
   printLabelInt("Shader Engines:", agent_i->shader_engs, 1);
   printLabelInt("Shader Arrs. per Eng.:", agent_i->shader_arrs_per_sh_eng, 1);
-  if (!wsl_env)
+  if (!(wsl_env || dtif_env))
     printLabelInt("WatchPts on Addr. Ranges:", agent_i->max_addr_watch_pts, 1);
 
   if (agent_i->device_type == HSA_DEVICE_TYPE_GPU)
@@ -871,6 +886,8 @@ AcquireAndDisplayMemPoolInfo(const hsa_amd_memory_pool_t pool,
   hsa_status_t err;
   pool_info_t pool_i;
 
+  UNUSED(indent);
+
   err = AcquirePoolInfo(pool, &pool_i);
   RET_IF_HSA_ERR(err);
 
@@ -1022,6 +1039,8 @@ AcquireAndDisplayISAInfo(const hsa_isa_t isa, uint32_t indent) {
   hsa_status_t err;
   isa_info_t isa_i;
 
+  UNUSED(indent);
+
   isa_i.name_str = nullptr;
   err = AcquireISAInfo(isa, &isa_i);
   RET_IF_HSA_ERR(err);
@@ -1292,12 +1311,13 @@ int CheckInitialState(void) {
 // acccumulate information about those objects. Corresponding to each
 // Acquire-type function is a Display* function which display the
 // accumulated data in a formatted way.
-int main(int argc, char* argv[]) {
+int main() {
   hsa_status_t err;
 
   DetectWSLEnvironment();
+  DetectDTIFEnvironment();
 
-  if (!wsl_env && CheckInitialState()) {
+  if (!(wsl_env || dtif_env) && CheckInitialState()) {
     return 1;
   }
   err = hsa_init();
